# CHANGELOG

<!-- version list -->

## v1.7.2 (2026-02-02)

### Bug Fixes

- How ABI Agent loads templatable sparql query
  ([`fa80a8c`](https://github.com/jupyter-naas/abi/commit/fa80a8c83f19e485b6d01abbb0573f58e214f517))


## v1.7.1 (2026-01-26)

### Bug Fixes

- CICD checks
  ([`1cc9a0d`](https://github.com/jupyter-naas/abi/commit/1cc9a0d8aa9e5b89c06269f11b8437d3a60d2c23))


## v1.7.0 (2026-01-24)


## v1.6.0 (2026-01-24)

### Features

- Working on improving project initialization
  ([`e7063bb`](https://github.com/jupyter-naas/abi/commit/e7063bb63a7d3b553f159861fb3e1c545e7d8849))


## v1.5.1 (2026-01-16)


## v1.5.0 (2026-01-15)


## v1.4.2 (2026-01-08)

### Bug Fixes

- Pandas-stubs lib version
  ([`343d981`](https://github.com/jupyter-naas/abi/commit/343d981689c044c87c89ce2bf3fc1d5065acde55))

- Tipo license
  ([`f639213`](https://github.com/jupyter-naas/abi/commit/f639213b6c680d211c9618737842f01b51a65f8d))

- Tipo license
  ([`0269100`](https://github.com/jupyter-naas/abi/commit/0269100ca7d2d338d1f68be0717be6e981cc8eac))


## v1.4.1 (2026-01-08)

### Bug Fixes

- Add project urls in pyproject.toml
  ([`c155efa`](https://github.com/jupyter-naas/abi/commit/c155efa2a794b44312eb90ae19ab1c0da402d3ef))

### Documentation

- Add README.md to naas-abi-core
  ([`dc42682`](https://github.com/jupyter-naas/abi/commit/dc4268204d14a396945b34ad5f3bac38fbf7a7cb))


## v1.4.0 (2026-01-02)

### Bug Fixes

- Add default logo api
  ([`0036796`](https://github.com/jupyter-naas/abi/commit/0036796586ac904879f4dd1fa4a40a400bd0e4ef))

- Error aws neptune
  ([`76ffc39`](https://github.com/jupyter-naas/abi/commit/76ffc39a0d9408a68d39bf704172c4ff5f5d98c3))

- Remove connections from api doc
  ([`4f629bf`](https://github.com/jupyter-naas/abi/commit/4f629bf0df5e3f3df30453f2531879301b05252d))

### Features

- Add boto3-stubs
  ([`47dccd1`](https://github.com/jupyter-naas/abi/commit/47dccd144ab4811c1c4e481287b39026d07bb7ec))

### Refactoring

- Move workflows ontology yaml to naas module
  ([`b4e8e9f`](https://github.com/jupyter-naas/abi/commit/b4e8e9fd738a338c462c9df2525e043cfdf5095d))


## v1.3.0 (2026-01-02)

### Bug Fixes

- Get env value from .env if not in env
  ([`b984252`](https://github.com/jupyter-naas/abi/commit/b98425297e596142ee39ece11f6542ed713e4d4e))

- Improve config first pass loading for secret service
  ([`f598e79`](https://github.com/jupyter-naas/abi/commit/f598e7995e7984a6bbe51e1a7e8a4a34de121968))

- Missing f string + display config file name in debug
  ([`17e4bac`](https://github.com/jupyter-naas/abi/commit/17e4bac2541642aa97fe5f59522c6cbc578c60fa))

- Remove duplicated logger
  ([`7e9ffb8`](https://github.com/jupyter-naas/abi/commit/7e9ffb81023126fe56c3150aba12e885260956a8))

- Update package management & add types-pyyaml
  ([`5a66600`](https://github.com/jupyter-naas/abi/commit/5a666002264744f571015ac45eef3e583b458f40))

### Documentation

- Add docstring
  ([`76766b9`](https://github.com/jupyter-naas/abi/commit/76766b9acafee1d0dc5b2ee32057b0c3e5a0ba75))

### Features

- Test adaptors dotenv & naas
  ([`d3b7204`](https://github.com/jupyter-naas/abi/commit/d3b7204f663f4ed969446db8475d97197227336b))


## v1.2.1 (2025-12-30)


## v1.2.0 (2025-12-19)

### Bug Fixes

- Inject naas_abi_core.modules.templatablesparqlquery by default
  ([`b6dc785`](https://github.com/jupyter-naas/abi/commit/b6dc78519e71afb46dd2ffc401539fab19fb865f))

- Review
  ([`6301a5f`](https://github.com/jupyter-naas/abi/commit/6301a5fcda63875b2748a625727903f236772966))

- Review
  ([`1ad319b`](https://github.com/jupyter-naas/abi/commit/1ad319ba2e47463ab84cabf7edbd2b721b053e3b))

### Chores

- Remove comments
  ([`05868ff`](https://github.com/jupyter-naas/abi/commit/05868ff0c60ccb3e7da46cdd8903d207622d5e8c))

- Remove duplicate logger
  ([`8438450`](https://github.com/jupyter-naas/abi/commit/84384505a88b9645e56628b39bfda8da054792cc))

### Features

- Workin on naas-abi-cli
  ([`16cd62d`](https://github.com/jupyter-naas/abi/commit/16cd62d77879d94c83fae9218bd451c1909554e4))


## v1.1.2 (2025-12-05)

### Bug Fixes

- Make it possible to define env secrets from config.yaml
  ([`d9903cf`](https://github.com/jupyter-naas/abi/commit/d9903cfecac03df40a6f3076c7ff44229c0c12cd))


## v1.1.1 (2025-12-05)


## v1.1.0 (2025-12-05)

### Features

- Make it possible to add env var using cli deploy
  ([`eb32c8d`](https://github.com/jupyter-naas/abi/commit/eb32c8d9613ecbddb3a891f25db0a5bc3498b258))


## v1.0.8 (2025-12-05)


## v1.0.7 (2025-12-03)

### Bug Fixes

- Working on embedding assets in the release
  ([`9737428`](https://github.com/jupyter-naas/abi/commit/97374285cb3c79ed03399859c58b8cac6373627d))

- **marketplace**: Convert applications.pubmed to a real module
  ([`b9ac395`](https://github.com/jupyter-naas/abi/commit/b9ac395c0e90980fb19379d40ae5017efcf06d1d))


## v1.0.6 (2025-12-02)

### Bug Fixes

- Working on abi cli
  ([`e1c11a1`](https://github.com/jupyter-naas/abi/commit/e1c11a15a80403fdb1992faa4dcb035fbaf9b5c0))


## v1.0.5 (2025-12-02)

### Bug Fixes

- Working on dependencies
  ([`cfb492f`](https://github.com/jupyter-naas/abi/commit/cfb492f5f1604d405ff0221d505e90101614d59e))


## v1.0.4 (2025-12-02)

### Bug Fixes

- Update release commit parser option
  ([`6eabfd8`](https://github.com/jupyter-naas/abi/commit/6eabfd8f61681240a1974affd377b983bd7885a9))
## v1.0.4-dev.2 (2025-12-02)


## v1.0.4-dev.1 (2025-12-02)

### Bug Fixes

- **naas_abi_core**: Working on dependencies
  ([`54ad989`](https://github.com/jupyter-naas/abi/commit/54ad9896794cf831e503aef22170a0b0485e9e31))


## v1.0.3-dev.1 (2025-12-01)
## v1.0.3 (2025-12-01)

### Bug Fixes

- Working on fixing mypy check for core and naas-abi-marketplace linkedin
  ([`fc11437`](https://github.com/jupyter-naas/abi/commit/fc11437fa5b655805327783016318416d17a0f1b))


## v1.0.2 (2025-12-01)

### Bug Fixes

- Working on fixing mcp-server
  ([`69ba291`](https://github.com/jupyter-naas/abi/commit/69ba291474a171da1652a8769493d35f3d2d3843))


## v1.0.1 (2025-12-01)

### Bug Fixes

- Working on api tests in CI/CD
  ([`5012a3b`](https://github.com/jupyter-naas/abi/commit/5012a3b4408f138d6e5c90a36c6f4d250f56af8a))


## v1.0.0 (2025-12-01)
## v1.0.0-dev.10 (2025-12-01)

### Bug Fixes

- Adding authors and removing uneeded configuration
  ([`c105454`](https://github.com/jupyter-naas/abi/commit/c105454bcb1ed1da88bda6ca23a05e9e3e9c1ed1))

- Configure release on main
  ([`fb32b93`](https://github.com/jupyter-naas/abi/commit/fb32b93ef0e3ce1b8bb291fda902a7a03c0f0646))


## v1.0.0-dev.9 (2025-11-30)

### Bug Fixes

- Working on api deployment
  ([`8a803ba`](https://github.com/jupyter-naas/abi/commit/8a803bad5db9ed9d020d18245b3b6fbafda6bb2c))


## v1.0.0-dev.8 (2025-11-30)


## v1.0.0-dev.7 (2025-11-30)


## v1.0.0-dev.6 (2025-11-30)


## v1.0.0-dev.5 (2025-11-30)

### Bug Fixes

- Working on ci/cd
  ([`d65250c`](https://github.com/jupyter-naas/abi/commit/d65250c10e433595a6ecd124c33aee9ca7e69535))


## v1.0.0-dev.4 (2025-11-30)

### Bug Fixes

- Working on ci
  ([`ba918da`](https://github.com/jupyter-naas/abi/commit/ba918da13147636ec732f2aba3e2978046b93970))


## v1.0.0-dev.3 (2025-11-30)

### Bug Fixes

- Uv install
  ([`c268208`](https://github.com/jupyter-naas/abi/commit/c268208bdcc69223fbb68114978211de7c161956))


## v1.0.0-dev.2 (2025-11-30)

### Bug Fixes

- Remove scoped prefix for semantic releases
  ([`c208c3f`](https://github.com/jupyter-naas/abi/commit/c208c3f12ad1cd2eb2264a166f0e683184efb2ca))


## v1.0.0-dev.1 (2025-11-30)

- Initial Release
